@@ -61,6 +61,7 @@ import html
 from ..django import get_list
 from ..django import get_key_from_request_data_or_self_obj
 from ..django.utils import get_field_type_in_db, get_field_type_in_py
+from bdtime.datetime_utils import common_date_time_formats
 
 
 IAdmin = admin.ModelAdmin
@@ -494,7 +495,6 @@ class ImportAdmin(IDAdmin):
                             content_ls[i] = _obj
 
                         if attr_field_name in ['DateField', 'DateTimeField']:
-                            # print(i, title_i, content_ls[i])
                             if attr_field_name == 'DateTimeField':
                                 res = conv_date_time_field_str_format(ts=content_ls[i])
                                 # if res is None:
@@ -502,9 +502,18 @@ class ImportAdmin(IDAdmin):
                                 content_ls[i] = res
                             else:
                                 ts = content_ls[i]
-                                res = conv_date_field_str_format(ts=ts)
-                                # if res is None:
-                                #     print(content_ls[i])
+                                res = conv_date_field_str_format(ts=ts) or conv_date_time_field_str_format(ts=content_ls[i])
+                                if res:
+                                    try:
+                                        if '.' in res:
+                                            res_dt = datetime.datetime.strptime(res, common_date_time_formats.ms_dt)
+                                        elif ':' in res:
+                                            res_dt = datetime.datetime.strptime(res, common_date_time_formats.s_dt)
+                                        else:
+                                            res_dt = datetime.datetime.strptime(res, common_date_time_formats.only_date)
+                                        res = res_dt.strftime(common_date_time_formats.only_date)
+                                    except Exception as e:
+                                        raise ValueError(f'字段[{title_i}]日期格式错误! 标准格式: [%Y-%m-%d]. error: {e}')
                                 content_ls[i] = res
 
                     dc = dict(zip(title_ls, content_ls))
@@ -522,6 +531,8 @@ class ImportAdmin(IDAdmin):
 
                     my_tqdm.update(1)
 
+                    # self.model.objects.create(**dc)
+
                     # if self.use_bulk_create is False:
                     #     self.model.objects.create(**dc)
 
