@@ -71,8 +71,13 @@ def get_key_from_request_data_or_self_obj(request_data, self_obj, key, get_type=
     """
     query_dc = request_data
 
+    # 让request携带的数据可以覆盖自身的key值
+    ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
+
     if get_type == 'list':
         value = get_list(query_dc, key)
+        ret = value if value not in [None, [], ['']] else ret_0
+        return ret
     elif get_type == 'bool':
         value = query_dc.get(key)
         ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
@@ -81,11 +86,8 @@ def get_key_from_request_data_or_self_obj(request_data, self_obj, key, get_type=
         return bool(ret)
     else:
         value = query_dc.get(key)
-
-    # 让request携带的数据可以覆盖自身的key值
-    ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
-    ret = value if value is not None else ret_0
-    return ret
+        ret = value if value is not None else ret_0
+        return ret
 
 
 def set_query_dc_value(query_dc: (QueryDict, dict), new_dc: dict):
